--- old/usr/src/lib/libm/common/Q/logbl.c	2019-06-06 20:38:51.256992010 +0000
+++ new/usr/src/lib/libm/common/Q/logbl.c	2019-06-06 20:38:51.274713520 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,23 +31,27 @@
 #pragma weak __logbl = logbl
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
-#define	_C99SUSv3_logb	_C99SUSv3_logb_subnormal_is_like_ilogb
+#include "xpg6.h"			/* __xpg6 */
+#define	_C99SUSv3_logb		_C99SUSv3_logb_subnormal_is_like_ilogb
 
 #if defined(__sparc)
-#define	ISNORMALL(k, x)	(k != 0x7fff)			/* assuming k != 0 */
+#define	ISNORMALL(k, x)		(k != 0x7fff)	/* assuming k != 0 */
 #define	X86PDNRM(k, x)
-#define	XSCALE_OFFSET	0x406f				/* 0x3fff + 112 */
+#define	XSCALE_OFFSET		0x406f		/* 0x3fff + 112 */
+
 static const long double xscale = 5192296858534827628530496329220096.0L;
-								/* 2^112 */
+
+/* 2^112 */
 #elif defined(__x86)
 /*
  * if pseudo-denormal, replace by the equivalent normal
  */
-#define	X86PDNRM(k, x)	if (k == 0 && (((int *) &x)[1] & 0x80000000) != 0) \
-				((int *) &x)[2] |= k = 1
-#if defined(HANDLE_UNSUPPORTED)				/* assuming k != 0 */
-#define	ISNORMALL(k, x)	(k != 0x7fff && (((int *) &x)[1] & 0x80000000) != 0)
+#define	X86PDNRM(k, x)	\
+	if (k == 0 && (((int *)&x)[1] & 0x80000000) !=	0) \
+		((int *)&x)[2] |= k = 1
+#if defined(HANDLE_UNSUPPORTED)		/* assuming k != 0 */
+#define	ISNORMALL(k, x)	(k != 0x7fff && (((int *)&x)[1] & 0x80000000) != \
+	0)
 #else
 #define	ISNORMALL(k, x)	(k != 0x7fff)
 #endif
@@ -55,27 +60,34 @@
 #endif
 
 static long double
-raise_division(long double v) {
+raise_division(long double v)
+{
 #pragma STDC FENV_ACCESS ON
+
 	static const long double zero = 0.0L;
+
 	return (v / zero);
 }
 
 long double
-logbl(long double x) {
+logbl(long double x)
+{
 	int k = XBIASED_EXP(x);
 
 	X86PDNRM(k, x);
+
 	if (k == 0) {
-		if (ISZEROL(x))
+		if (ISZEROL(x)) {
 			return (raise_division(-1.0L));
-		else if ((__xpg6 & _C99SUSv3_logb) != 0) {
-			x *= xscale;		/* scale up by 2^112 or 2^63 */
-			return (long double) (XBIASED_EXP(x) - XSCALE_OFFSET);
-		} else
+		} else if ((__xpg6 & _C99SUSv3_logb) != 0) {
+			x *= xscale;	/* scale up by 2^112 or 2^63 */
+			return ((long double)(XBIASED_EXP(x) - XSCALE_OFFSET));
+		} else {
 			return (-16382.L);
-	} else if (ISNORMALL(k, x))
-		return ((long double) (k - 0x3fff));
-	else
+		}
+	} else if (ISNORMALL(k, x)) {
+		return ((long double)(k - 0x3fff));
+	} else {
 		return (x * x);
+	}
 }
